Skip to contents

Returns a function with the .runner contract (experiments, ...) that adds LLMR-shaped response columns. The per-row response text is decided by responder, a function (text) -> character. Results are marked as demo.

Usage

demo_runner(
  responder = NULL,
  text_cols = c("text", "unit", "document", "prompt", "input")
)

# S3 method for class 'llmrshiny_demo_result'
print(x, ...)

Arguments

responder

A function mapping a single input text to a response string. Defaults to echoing a short stub.

text_cols

Candidate column names to read the input text from.

x

A demo result.

...

Passed to the next print method.

Value

A runner function of class llmrshiny_demo_runner.