Extract call/token counts from a result frame
Usage
extract_token_counts(x, fallback_calls = 0L)
Arguments
- x
A result data frame (or list containing one).
- fallback_calls
Call count to use when x has no result frame.
Value
A list with token totals and either calls, when explicit call
provenance is available, or result_rows.