Skip to contents

Model defaults are optional because provider aliases can change between package releases. Set the LLMR.shiny.default_models option to a named character vector to supply local defaults.

Usage

provider_registry(
  default_models = getOption("LLMR.shiny.default_models", character())
)

Arguments

default_models

A named character vector of provider model defaults.

Value

A data frame of provider, display, and default_model.