Skip to contents

Call once at the top of a GUI's server with the top-level input, output, session. It keeps the model field in sync with the provider, renders the key and usage tiles, tracks usage, and returns a list of reactives and mutators (provider, model, mode, key, can_run, set_plan, add_usage) for the per-package modules to consume.

Usage

shell_context(input, output, session)

Arguments

input, output, session

The top-level Shiny server arguments.

Value

A shared-context list.