Model defaults are optional because provider aliases can change between
package releases. Set the LLMR.shiny.default_models option to a named
character vector to supply local defaults.
Model defaults are optional because provider aliases can change between
package releases. Set the LLMR.shiny.default_models option to a named
character vector to supply local defaults.